@@ -6,6 +6,7 @@ import os
 import tempfile
 from pathlib import Path
 from textwrap import dedent
+from unittest.mock import patch
 
 import pytest
 
@@ -96,7 +97,7 @@ def test_name_include_untracked(git_diff):
         ),
     ],
 )
-def test_git_path_selection(mocker, diff, git_diff, include, exclude, expected):
+def test_git_path_selection(diff, git_diff, include, exclude, expected):
     old_cwd = os.getcwd()
     with tempfile.TemporaryDirectory() as tmp_dir:
         # change the working directory into the temp directory so that globs are working
@@ -127,15 +128,15 @@ def test_git_path_selection(mocker, diff, git_diff, include, exclude, expected):
         )
 
         # Get the source paths in the diff
-        mocker.patch.object(os.path, "abspath", lambda path: f"{tmp_dir}/{path}")
-        source_paths = diff.src_paths_changed()
+        with patch.object(os.path, "abspath", lambda path: f"{tmp_dir}/{path}"):
+            source_paths = diff.src_paths_changed()
 
         # Validate the source paths
         # They should be in alphabetical order
         assert source_paths == expected
 
-    # change back to the previous working directory
-    os.chdir(old_cwd)
+        # change back to the previous working directory
+        os.chdir(old_cwd)
 
 
 def test_git_source_paths(diff, git_diff):
@@ -383,7 +384,6 @@ def test_inter_diff_conflict(diff, git_diff):
     # Delete the lines we modified
     deleted_lines = []
     for line in added_diff.split("\n"):
-
         # Any added line becomes a deleted line
         if line.startswith("+"):
             deleted_lines.append(line.replace("+", "-"))
@@ -406,7 +406,7 @@ def test_inter_diff_conflict(diff, git_diff):
         (added_diff, deleted_diff, deleted_diff),
     ]
 
-    for (main_diff, staged_diff, unstaged_diff) in combinations:
+    for main_diff, staged_diff, unstaged_diff in combinations:
         # Set up so we add lines, then delete them
         _set_git_diff_output(diff, git_diff, main_diff, staged_diff, unstaged_diff)
         assert diff.lines_changed("file.py") == []
@@ -473,7 +473,6 @@ def test_git_diff_error(
     ]
 
     for diff_str in err_outputs:
-
         # Configure the git diff output
         _set_git_diff_output(diff, git_diff, diff_str, "", "")
 
