@@ -218,6 +218,11 @@ class TestDiffCoverIntegration(ToolsIntegrationBase):
             "git_diff_add.txt", "add_console_report.txt", ["diff-cover", "coverage.xml"]
         )
 
+    def test_added_file_console_lcov(self):
+        self._check_console_report(
+            "git_diff_add.txt", "add_console_report.txt", ["diff-cover", "lcov.info"]
+        )
+
     def test_lua_coverage(self):
         """
         coverage report shows that diff-cover needs to normalize
@@ -317,6 +322,13 @@ class TestDiffCoverIntegration(ToolsIntegrationBase):
             ["diff-cover", "coverage1.xml", "coverage2.xml"],
         )
 
+    def test_changed_file_lcov_console(self):
+        self._check_console_report(
+            "git_diff_changed.txt",
+            "changed_console_report.txt",
+            ["diff-cover", "lcov.info"],
+        )
+
     def test_subdir_coverage_html(self):
         """
         Assert that when diff-cover is ran from a subdirectory it
@@ -409,7 +421,6 @@ class TestDiffQualityIntegration(ToolsIntegrationBase):
     tool_module = "diff_cover.diff_quality_tool"
 
     def test_git_diff_error_diff_quality(self):
-
         # Patch the output of `git diff` to return an error
         self._set_git_diff_output("", "fatal error", 1)
 
@@ -520,7 +531,6 @@ class TestDiffQualityIntegration(ToolsIntegrationBase):
         )
 
     def test_pre_generated_pycodestyle_report(self):
-
         # Pass in a pre-generated pycodestyle report instead of letting
         # the tool call pycodestyle itself.
         self._check_console_report(
@@ -530,7 +540,6 @@ class TestDiffQualityIntegration(ToolsIntegrationBase):
         )
 
     def test_pre_generated_pyflakes_report(self):
-
         # Pass in a pre-generated pyflakes report instead of letting
         # the tool call pyflakes itself.
         self._check_console_report(
@@ -540,7 +549,6 @@ class TestDiffQualityIntegration(ToolsIntegrationBase):
         )
 
     def test_pre_generated_pylint_report(self):
-
         # Pass in a pre-generated pylint report instead of letting
         # the tool call pylint itself.
         self._check_console_report(
